@@ -416,7 +416,7 @@ void Amor::slotMouseClicked(const QPoint &pos)
         mMenu = new KPopupMenu();
 	mMenu->insertTitle("Amor"); // I really don't want this i18n'ed
         mMenu->insertItem(i18n("&Options..."), this, SLOT(slotConfigure()));
-        mMenu->insertItem(i18n("&About..."), this, SLOT(slotAbout()));
+        mMenu->insertItem(i18n("&About"), this, SLOT(slotAbout()));
         mMenu->insertSeparator();
         mMenu->insertItem(i18n("&Quit"), kapp, SLOT(quit()));
     }
