@@ -8,8 +8,7 @@
 #include <stdio.h>
 #include <time.h>
 
-#include <kconfig.h>
-#include <kuniqueapp.h>
+#include <kuniqueapplication.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
