@@ -76,7 +76,8 @@ void FifteenApplet::about()
 	_aboutData = new KAboutData("kfifteenapplet", I18N_NOOP("KFifteenApplet"), "1.0",
                                     I18N_NOOP("Fifteen pieces applet.\n\n"
                                               "The goal is to put the sliding pieces into numerical order.\n"
-                                              "Select \"Randomize Pieces\" from the RMB menu to start a game."),
+                                              "Select \"Randomize Pieces\" from the right mouse button menu\n"
+                                              "to start a game."),
                                     KAboutData::License_BSD, "(c) 2001, Matthias Elter");
 	_aboutData->addAuthor("Matthias Elter", 0, "elter@kde.org");
     }
