@@ -716,7 +716,7 @@ void WeatherLib::processData(QString metar, Data *d){
 			break;
 
 		// Don't try to parse the ICAO location code
-		if ((!found) && (*it == d->reportLocation))
+		if ((!found) && (*it == d->reportLocation.upper().stripWhiteSpace()))
 		{
 			found = true;
 			continue;
