@@ -4,7 +4,7 @@
 
 #include <qstring.h>
 #include <qstringlist.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 
 class QPainter;
@@ -15,7 +15,6 @@ class City
 public:
 
   City(QString n, double la, double lo) : _name(n), _latitude(la), _longitude(lo) {};
-
   QString name() { return _name; };
 
   double latitude() { return _latitude; };
@@ -35,7 +34,7 @@ class CityList
 public:
 
   CityList();
-
+  ~CityList();
   void paint(QPainter *p, int width, int height, int offset);
   
   City *getNearestCity(int w, int h, int offset, int x, int y, QPoint &where);
@@ -53,7 +52,7 @@ private:
 
 private:
 
-  QList<City> _cities;
+  QPtrList<City> _cities;
 
 };
 
