@@ -1,13 +1,10 @@
 #include <stdlib.h>
-#include <iostream.h>
-#include <stdio.h>
 
 
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qwidget.h>
 #include <qpixmap.h>
-#include <qimage.h>
 
 
 #include <kapplication.h>
@@ -15,7 +12,6 @@
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
-#include <kimageio.h>
 #include <kdebug.h>
 
 
@@ -27,6 +23,8 @@
 WorldWideWatch::WorldWideWatch(bool restore, QWidget *parent, const char *name)
   : KMainWindow(parent, name)
 {
+  KGlobal::locale()->insertCatalogue("timezones"); // For time zone translation
+
   QWidget *w = new QWidget(this);
   setCentralWidget(w);
 
@@ -140,9 +138,12 @@ int main(int argc, char *argv[])
   KUniqueApplication::addCmdLineOptions();
 
   if (!KUniqueApplication::start())
-    exit(0);
+    return 0;
 
   WatchApplication app;
+  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+  if (args->isSet("dump"))
+      app.disableSessionManagement();
 
   if (app.isRestored())
     RESTORE(WorldWideWatch)
