@@ -10,6 +10,7 @@
 #include <qstringlist.h>
 #include <qlabel.h>
 #include <qpoint.h>
+#include <qtimer.h>
 
 
 class QPopupMenu;
@@ -57,7 +58,7 @@ signals:
 protected slots:
 
   void timeout();
-
+  void updateCityIndicator();
 
 public slots:
 
@@ -121,7 +122,7 @@ private:
   QPoint _flagPos;
  
   bool _applet;
-
+  QTimer m_timer;
 };
 
 
